@@ -377,12 +377,8 @@ def formatResults(name, sectorSize, before, after, error, timeout):
         read_ms = None
         write_ms = None
 
-    twisted_version = twisted.version._getSVNVersion()
-    if twisted_version is None:
-        twisted_version = twisted.version.short()
-    epsilon_version = epsilon.version._getSVNVersion()
-    if epsilon_version is None:
-        epsilon_version = epsilon.version.short()
+    twisted_version = twisted.version.short()
+    epsilon_version = epsilon.version.short()
 
     Results(
         version=STATS_VERSION,
@@ -416,19 +412,23 @@ def reportResults(results):
 
 
 
-def discoverCurrentWorkingDevice():
+def discoverCurrentWorkingDevice(procMounts='/proc/self/mounts'):
     """
     Return a short string naming the device which backs the current working
     directory, ie C{/dev/hda1}.
     """
     possibilities = []
     cwd = os.getcwd()
-    for L in file('/proc/self/mounts'):
-        parts = L.split()
-        if cwd.startswith(parts[1]):
-            possibilities.append((len(parts[1]), parts[0]))
+    with file(procMounts, 'rb') as f:
+        for L in f:
+            parts = L.split()
+            if cwd.startswith(parts[1]):
+                possibilities.append((len(parts[1]), parts[0]))
     possibilities.sort()
-    return possibilities[-1][-1]
+    try:
+        return possibilities[-1][-1]
+    except IndexError:
+        return '<unknown>'
 
 
 
